@@ -1,4 +1,4 @@
-/*  $Id: xfce_support.c,v 1.69 2004/12/14 11:51:09 jasper Exp $
+/*  $Id: xfce_support.c 4297 2005-01-17 00:54:49Z kelnos $
  *  
  *  Copyright 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *  
@@ -571,7 +571,7 @@ real_select_file (const char *title, const char *path,
             char *current, *full;
 
             current = g_get_current_dir ();
-            full = g_build_filename (current, path);
+            full = g_build_filename (current, path, NULL);
 
             xfce_file_chooser_set_filename(XFCE_FILE_CHOOSER(fs), full);
 
