@@ -1,4 +1,4 @@
-/*  $Id: xfce_settings_plugin.c,v 1.28 2004/12/14 11:51:10 jasper Exp $
+/*  $Id: xfce_settings_plugin.c 4321 2005-02-01 07:30:36Z jasper $
  *
  *  Copyright 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *
@@ -238,7 +238,7 @@ old_xml_read_options (const char *path)
     GMarkupParser *parser;
     GMarkupParseContext *context;
     char *contents;
-    int len;
+    gsize len;
     GError *error = NULL;
 
     if (!g_file_get_contents (path, &contents, &len, &error))
